<img src="docs/images/sDRIPS_Logo/Logo.png" alt="sDRIPS" width="200"/>

# satellite Data Rendered Irrigation using Penman and SEBAL (sDRIPS) 

sDRIPS is an open-source Python package that generates weekly, farm-scale (30 m) irrigation advisories by integrating satellite observations, global weather models, and ground-based measurements when available. Its modular design supports diverse agricultural contexts and heterogeneous data inputs, allowing estimation of evapotranspiration, incorporation of precipitation forecasts, and calculation of net irrigation demand. sDRIPS is designed to make advanced irrigation planning accessible to farmers and canal operators of varying technical expertise, enabling optimized water use under climate uncertainty.

### How to Cite
<div style="text-align: justify;">

- Khan, S; Hossain, F.(2025). sDRIPS: A Cloud-Based, Open-Source Python Package for Satellite-Informed Surface Water Irrigation Optimization, <i>Digital Water.</i>  
- Khan, S; Hossain, F.; Islam, K.; Ahamed, M.(2025). Satellite Data Rendered Irrigation using Penman-Monteith and SEBAL - sDRIPS for Surface Water Irrigation Optimization, <i>Hydrology and Earth System Sciences (HESS).</i>
</div>

### Read The Docs Documentation
Detailed guide with step-by-step tutorial on sDRIPS can be found on ReadTheDocs page - [https://sdrips.readthedocs.io/en/latest/](https://sdrips.readthedocs.io/en/latest/). 